==> touhoulittlemaid-fabric-1.21.1-0.0.2-neo1.2.2-sources.jar: com/github/tartaricacid/touhoulittlemaid/entity/task/TaskFeedOwner.java <==
package com.github.tartaricacid.touhoulittlemaid.entity.task;

import com.github.tartaricacid.touhoulittlemaid.TouhouLittleMaid;
import com.github.tartaricacid.touhoulittlemaid.api.task.IFeedTask;
import com.github.tartaricacid.touhoulittlemaid.entity.ai.brain.task.MaidFeedOwnerTask;
import com.github.tartaricacid.touhoulittlemaid.entity.passive.EntityMaid;
import com.github.tartaricacid.touhoulittlemaid.init.InitSounds;
import com.github.tartaricacid.touhoulittlemaid.util.SoundUtil;
import com.google.common.collect.Lists;
import com.mojang.datafixers.util.Pair;
import javax.annotation.Nullable;
import net.minecraft.class_1293;
import net.minecraft.class_1294;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1839;
import net.minecraft.class_2960;
import net.minecraft.class_3414;
import net.minecraft.class_3419;
import net.minecraft.class_4081;
import net.minecraft.class_4174;
import net.minecraft.class_7893;
import net.minecraft.class_9334;
import java.util.List;

public class TaskFeedOwner implements IFeedTask {
    public static final class_2960 UID = class_2960.method_60655(TouhouLittleMaid.MOD_ID, "feed");

    @Override
    public class_2960 getUid() {
        return UID;
    }

    @Override
    public class_1799 getIcon() {
        return class_1802.field_8176.method_7854();
    }

    @Override
    public boolean isFood(class_1799 stack, class_1657 owner) {
        if (stack.method_7909() == class_1802.field_8103) {
            for (class_1293 effect : owner.method_6026()) {
                if (isHarmfulEffect(effect) && effect.method_5584() > 60 /*&& effect.getCures().contains(EffectCures.MILK)*/) {
                    return true;
                }
            }
            return false;
        }
        //if (stack.getItem().getFoodProperties(stack, owner) != null) {
        if (stack.method_57824(class_9334.field_50075) != null) {
            //FoodProperties food = stack.getItem().getFoodProperties(stack, owner);
            class_4174 food = stack.method_57824(class_9334.field_50075);
            if (food != null) {
                return food.comp_2495().isEmpty() ||
                        food.comp_2495().stream().noneMatch(effect -> isHarmfulEffect(effect.comp_2496()));
            }
        }
        return false;
    }

    @Override
    public Priority getPriority(class_1799 stack, class_1657 owner) {
        if (stack.method_31574(class_1802.field_8103)) {
            return Priority.HIGH;
        }

        // 蜂蜜瓶可以清除中毒效果，所以当玩家拥有中毒效果时，应当优先使用
        //if (stack.is(Items.HONEY_BOTTLE) && owner.getActiveEffects().stream().anyMatch(effect -> effect.getCures().contains(EffectCures.HONEY))) {
        if (stack.method_31574(class_1802.field_20417) && owner.method_6026().stream().anyMatch(effect -> effect.method_55654(class_1294.field_5899))) {
            return Priority.HIGH;
        }
        ;
        if (stack.method_31574(class_1802.field_8463)) {
            if (owner.method_6032() * 2 < owner.method_6063()) {
                return Priority.HIGH;
            } else {
                return Priority.LOWEST;
            }
        }

        //if (stack.getItem().getFoodProperties(stack, owner) != null) {
        if (stack.method_57824(class_9334.field_50075) != null) {
            //FoodProperties food = stack.getItem().getFoodProperties(stack, owner);
            class_4174 food = stack.method_57824(class_9334.field_50075);
            int heal = 0;
            if (food != null) {
                heal = food.comp_2491();
            }
            int hunger = 20 - owner.method_7344().method_7586();
            if (heal == hunger) {
                return Priority.HIGH;
            } else if (heal > hunger) {
                return Priority.LOWEST;
            } else {
                return Priority.LOW;
            }
        }

        return Priority.NONE;
    }

    @Override
    public class_1799 feed(class_1799 stack, class_1657 owner) {
        if (stack.method_7976() == class_1839.field_8946) {
            owner.field_6002.method_43129(null, owner, stack.method_21832(), class_3419.field_15254,
                    0.5f, owner.field_6002.method_8409().method_43057() * 0.1f + 0.9f);
        }
        return stack.method_7909().method_7861(stack, owner.field_6002, owner);
    }

    @Nullable
    @Override
    public class_3414 getAmbientSound(EntityMaid maid) {
        return SoundUtil.environmentSound(maid, InitSounds.MAID_FEED, 0.3f);
    }

    @Override
    public List<Pair<Integer, class_7893<? super EntityMaid>>> createBrainTasks(EntityMaid maid) {
        return Lists.newArrayList(Pair.of(5, new MaidFeedOwnerTask(this, 2, 0.6f)));
    }

    private boolean isHarmfulEffect(class_1293 effect) {
        return effect.method_5579().comp_349().method_18792() == class_4081.field_18272;
    }
}

==> touhoulittlemaid-fabric-1.21.1-0.0.7-neo1.3.6-sources.jar: com/github/tartaricacid/touhoulittlemaid/entity/task/TaskFeedOwner.java <==
package com.github.tartaricacid.touhoulittlemaid.entity.task;

import com.github.tartaricacid.touhoulittlemaid.TouhouLittleMaid;
import com.github.tartaricacid.touhoulittlemaid.api.task.IFeedTask;
import com.github.tartaricacid.touhoulittlemaid.entity.ai.brain.task.MaidFeedOwnerTask;
import com.github.tartaricacid.touhoulittlemaid.entity.passive.EntityMaid;
import com.github.tartaricacid.touhoulittlemaid.init.InitSounds;
import com.github.tartaricacid.touhoulittlemaid.util.SoundUtil;
import com.google.common.collect.Lists;
import com.mojang.datafixers.util.Pair;
import javax.annotation.Nullable;
import net.minecraft.class_1293;
import net.minecraft.class_1294;
import net.minecraft.class_1657;
import net.minecraft.class_1702;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1839;
import net.minecraft.class_2960;
import net.minecraft.class_3414;
import net.minecraft.class_3419;
import net.minecraft.class_4081;
import net.minecraft.class_4174;
import net.minecraft.class_7893;
import net.minecraft.class_9334;
import java.util.List;

public class TaskFeedOwner implements IFeedTask {
    public static final class_2960 UID = class_2960.method_60655(TouhouLittleMaid.MOD_ID, "feed");

    @Override
    public class_2960 getUid() {
        return UID;
    }

    @Override
    public class_1799 getIcon() {
        return class_1802.field_8176.method_7854();
    }

    @Override
    public boolean isFood(class_1799 stack, class_1657 owner) {
        if (stack.method_7909() == class_1802.field_8103) {
            for (class_1293 effect : owner.method_6026()) {
                if (isHarmfulEffect(effect) && effect.method_5584() > 60 /*&& effect.getCures().contains(EffectCures.MILK)*/) {
                    return true;
                }
            }
            return false;
        }
        //if (stack.getItem().getFoodProperties(stack, owner) != null) {
        if (stack.method_57824(class_9334.field_50075) != null) {
            //FoodProperties food = stack.getItem().getFoodProperties(stack, owner);
            class_4174 food = stack.method_57824(class_9334.field_50075);
            if (food != null) {
                return food.comp_2495().isEmpty() ||
                        food.comp_2495().stream().noneMatch(effect -> isHarmfulEffect(effect.comp_2496()));
            }
        }
        return false;
    }

    @Override
    public Priority getPriority(class_1799 stack, class_1657 owner) {
        if (stack.method_31574(class_1802.field_8103)) {
            return Priority.HIGH;
        }

        // 蜂蜜瓶可以清除中毒效果，所以当玩家拥有中毒效果时，应当优先使用
        //if (stack.is(Items.HONEY_BOTTLE) && owner.getActiveEffects().stream().anyMatch(effect -> effect.getCures().contains(EffectCures.HONEY))) {
        if (stack.method_31574(class_1802.field_20417) && owner.method_6059(class_1294.field_5899)) {
            return Priority.HIGH;
        }
        ;
        if (stack.method_31574(class_1802.field_8463)) {
            if (owner.method_6032() * 2 < owner.method_6063()) {
                return Priority.HIGH;
            } else {
                return Priority.LOWEST;
            }
        }

        //if (stack.getItem().getFoodProperties(stack, owner) != null) {
        if (stack.method_57824(class_9334.field_50075) != null) {
            class_1702 foodData = owner.method_7344();
            if (!foodData.method_7587()) {
                return Priority.LOWEST;
            }
            //FoodProperties food = stack.getItem().getFoodProperties(stack, owner);
            class_4174 food = stack.method_57824(class_9334.field_50075);
            int heal = 0;
            if (food != null) {
                heal = food.comp_2491();
            }
            int hunger = 20 - foodData.method_7586();
            if (heal >= hunger) {
                return Priority.HIGH;
            } else {
                return Priority.LOW;
            }
        }

        return Priority.NONE;
    }

    @Override
    public class_1799 feed(class_1799 stack, class_1657 owner) {
        if (stack.method_7976() == class_1839.field_8946) {
            owner.field_6002.method_43129(null, owner, stack.method_21832(), class_3419.field_15254,
                    0.5f, owner.field_6002.method_8409().method_43057() * 0.1f + 0.9f);
        }
        return stack.method_7909().method_7861(stack, owner.field_6002, owner);
    }

    @Nullable
    @Override
    public class_3414 getAmbientSound(EntityMaid maid) {
        return SoundUtil.environmentSound(maid, InitSounds.MAID_FEED, 0.3f);
    }

    @Override
    public List<Pair<Integer, class_7893<? super EntityMaid>>> createBrainTasks(EntityMaid maid) {
        return Lists.newArrayList(Pair.of(5, new MaidFeedOwnerTask(this, 2, 0.6f)));
    }

    private boolean isHarmfulEffect(class_1293 effect) {
        return effect.method_5579().comp_349().method_18792() == class_4081.field_18272;
    }
}
